=========
ChangeLog
=========


v0.1.3
======

* Added support for human-friendly mode ("--human")


v0.1.2
======

* Added support for "isuser" command


v0.1.1
======

* First tagged release
* Support for bcrypt'ed passwords
